@@ -2,19 +2,7 @@ SNKMtest <- function(y, trt, n, dferror, mserror, alpha, dms.snkm)
 {
   Ybar   <- tapply(y, trt, mean)
   Ybar   <- sort(Ybar)
-  gap <- Ybar[2:n] - Ybar[1:(n - 1)]
-  auxpos2 <- max(gap)==gap
-  if(length(auxpos2[auxpos2 == T]) > 1){
-    valmax <- which(gap == max(gap))
-    auxpos <- min(c(n - valmax[1], valmax[1]))
-    for(i in valmax[-1]){
-      auxpos <- cbind(auxpos,min(c(n - i, i)))
-    }
-    auxpos <- which.max(auxpos)
-    posmax <- valmax[auxpos]
-  } else{
-    posmax <- as.integer(which.max(Ybar[2:n] - Ybar[1:(n - 1)]))
-  }
+  posmax <- as.integer(which.max(Ybar[2:n]-Ybar[1:(n-1)]))
   if (posmax >= (n - posmax))
   {
     Ymean <- mean(Ybar[1:posmax])
@@ -52,20 +40,8 @@ SNKMtest <- function(y, trt, n, dferror, mserror, alpha, dms.snkm)
     if (continua2==TRUE) {
       repeat {
         pos    <- pos + 1
-        gap <- Ybar[(pos + 1):(pos + range - 1)] - Ybar[pos:(pos + range - 2)]
-        auxpos2 <- max(gap)==gap
-        if(length(auxpos2[auxpos2 == T]) > 1){
-          valmax <- which(gap == max(gap))
-          auxpos <- min(c(range - valmax[1], valmax[1]))
-          for(i in valmax[-1]){
-            auxpos <- cbind(auxpos,min(c(n - i, i)))
-          }
-          auxpos <- which.max(auxpos)
-          posmax <- valmax[auxpos]
-        }else{
         posmax <- as.integer(which.max(Ybar[(pos + 1):(pos + range - 1)]
-                                         - Ybar[pos:(pos + range - 2)]))
-        }
+                                       - Ybar[pos:(pos + range - 2)]))
         if (posmax >= (pos + range - 1 - posmax)) {
           Ymean <- mean(Ybar[pos:(pos+posmax-1)])
         } else {
@@ -109,4 +85,4 @@ SNKMtest <- function(y, trt, n, dferror, mserror, alpha, dms.snkm)
   }
   result <- ProcTest(groups)
   return(group.test(result))
-}
\ No newline at end of file
+}
